@@ -24,7 +24,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Mo"
     author_url = "https://github.com/M-Davinci/dt_notify_to_people"
-    version = "1.7.2"
+    version = "1.7.3"
     resource_links = [
         ("Report Issue", "https://github.com/M-Davinci/dt_notify_to_people/issues"),
         ("View Source", "https://github.com/M-Davinci/dt_notify_to_people"),
@@ -65,6 +65,16 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
                     project, "custom_keyword", "DINGTALK_CUSTOM_KEYWORD"
                 ),
             },
+            {
+                "name": "number_alarm",
+                "label": "告警次数",
+                "type": "number",
+                "placeholder": "告警次数阀值",
+                "required": False,
+                "default": self.set_default(
+                    project, "number_alarm", "DINGTALK_CUSTOM_KEYWORD"
+                ),
+            },
             {
                 "name": "phones",
                 "label": "通知人员",
@@ -107,6 +117,8 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
 
     def _post(self, group, project):
         custom_keyword = self.get_option("custom_keyword", project)
+        # 告警次数阀值
+        number_alarm = self.get_option("number_alarm", project) if self.get_option("number_alarm", project) else 10
         phones = self.get_option("phones", project)
 
         issue_link = group.get_absolute_url(params={"referrer": "dingtalknotify"})
@@ -115,16 +127,15 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
 
         payload = f"## {custom_keyword}\n\n" if custom_keyword else ""
         payload = f"{payload} > 项目名称: {project.name} \n\n"
-        # payload = f"{payload} > status: {group.status} \n\n"
         payload = f"{payload} > 出现次数: {group.times_seen} \n\n"
-        payload = f"{payload} > 查看详情: <font color=blue>[{group.title if group.title else 'unknown'}]({issue_link})</font> \n\n"
+        payload = f"{payload} > 查看详情: <font color=blue>[{group.title if 'unknown' not in group.title else 'unknown'}]({issue_link})</font> \n\n"
         payload = f"{payload} > 具体报错: {group.message} \n\n"
         # payload = f"{payload} > 全部报错: {group} \n\n"
-        # payload = f"{payload} > 全部报错: {group.__dict__} \n\n"
+        payload = f"{payload} > 全部报错: {group.__dict__} \n\n"
         # payload = f"{payload} > 全部报错: {group.__dict__['_state'].__dict__} \n\n"
         # payload = f"{payload} > 全部报错: {group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__} \n\n"
-        payload = f"{payload} > _state: {group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__['_state'].__dict__} \n\n"
-        payload = f"{payload} > _state: {group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__['_state'].__dict__['fields_cache']['organization'].__dict__} \n\n"
+        # payload = f"{payload} > _state: {group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__['_state'].__dict__} \n\n"
+        # payload = f"{payload} > _state: {group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__['_state'].__dict__['fields_cache']['organization'].__dict__} \n\n"
         # payload = f"{payload} > flags: {group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__['flags'].__dict__} \n\n"
 
         payload = f"{payload} > _state: {project.__dict__} \n\n"
@@ -148,7 +159,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
 
         # 获取预设的阀值
         counts = self.get_option("warning_counts", project)
-        if int(group.status) == 0:
+        if int(group.status) == 0 and (group.times_seen > number_alarm):
             data_1 = {
                 "msgtype": "markdown",
                 "markdown": {
